# What is this?
wikipls is a Python package meant to easily scrape data out of Wikipedia (maybe more of the Wikimedia in the future), using the REST API.
Still early development, not releasing any versions yet.

# Versions
This version of the package is written in Python. I plan to eventually make a copy of this one written in Rust (using PyO3 and maturin).
Why Rust? It's an exercise for me, and it will be way faster and less error-prone

# Plans
- Support for more languages (Currently supports only English Wikipedia.
- Dictionary
- Citations
- Possibly change package name to WikiAnaly or something else
